<?php

namespace Fastrack\Location;

use Fastrack\Utilities\Api;
use SilverStripe\CMS\Controllers\ContentController;
use SilverStripe\Control\HTTPResponse;

class ApiController extends ContentController
{

	private static array $allowed_actions = [
		'places',
	];

	private static array $url_handlers = [
		'' => 'places',
	];

	public function places(): HTTPResponse
	{
		$CACHE_KEY = 'places';
		$places = Api::fetchFromCache($CACHE_KEY, []);
		if (!count($places)) {
			foreach (Place::get() as $place) {
				$placeData = self::buildPlace($place);
				$this->extend('updateBuildPlace', $placeData, $place);
				$places[] = $placeData;
			}
			Api::setCache($CACHE_KEY, $places);
		}
		return Api::constructResponse($this, $places);
	}

	public static function buildPlace(Place $place): array
	{
		$categories = [];
		foreach ($place->Categories() as $category) {
			$categories[] = self::buildCategory($category);
		}
		return [
			'id' => $place->ID,
			'slug' => $place->Slug,
			'name' => $place->Name,
			'excerpt' => $place->Excerpt,
			'content' => $place->Content,
			'image' => Api::buildImage($place->Image()),
			'website' => $place->Website,
			'phone' => $place->Phone,
			'email' => $place->Email,
			'latitude' => floatval($place->Latitude),
			'longitude' => floatval($place->Longitude),
			'address' => $place->getAddressFormatted(),
			'categories' => $categories,
		];
	}

	private static function buildCategory(PlaceCategory $category): array
	{
		$icon = $category->Image();
		return [
			'id' => $category->ID,
			'name' => $category->Name,
			'content' => $category->Content,
			'icon' => $icon->exists() ? $icon->ScaleMaxWidth(300)->Link() : null,
		];
	}

}
