<?php

namespace Fastrack\Location;


use PlatoCreative\Imgix\Imgix;
use SilverStripe\AssetAdmin\Forms\UploadField;
use SilverStripe\Core\Environment;
use SilverStripe\Forms\DropdownField;
use SilverStripe\Forms\FieldList;
use SilverStripe\Forms\TextField;
use SilverStripe\Forms\HiddenField;
use SilverStripe\Forms\TextareaField;
use SilverStripe\ORM\DataExtension;
use SilverStripe\View\Requirements;

class LocationExtension extends DataExtension
{
	private static array $db = [
		'Address1' => 'Varchar',
		'Address2' => 'Varchar',
		'City' => 'Varchar',
		'Postcode' => 'Varchar',
		'State' => 'Varchar',
		'Country' => 'Varchar',
		'Directions' => 'Text',
		'Latitude' => 'Varchar',
		'Longitude' => 'Varchar',
		'MapUrl' => 'Varchar'
	];

	private static array $has_one = [
		'Region' => Region::class,
		'SubRegion' => SubRegion::class,
		'MapPin' => Imgix::class,
	];

	private static array $translate = [
		'Address1',
		'Address2',
		'City',
		'Postcode',
		'State',
		'Country',
		'Directions',
	];


	public function updateCMSFields(FieldList $fields)
	{
		$tab = $fields->findOrMakeTab('Root.Location', 'Location');
		$tab->addExtraClass('location-tab-with-map');

		$regions = Region::get()->map('ID', 'Name')->push('0', 'No Region');

		$fields->addFieldsToTab('Root.Location', [
			TextField::create('Address1', 'Address one'),
			TextField::create('Address2', 'Address two'),
			TextField::create('City', 'City'),
			TextField::create('Postcode', 'Postcode'),
			TextField::create('State', 'State'),
			TextField::create('Country', 'Country'),
			DropdownField::create('RegionID', 'Region', $regions),
			$this->getSubRegionDropdown(),
			TextareaField::create('Directions', 'Directions'),
			TextField::create('MapUrl', 'Map URL'),
			HiddenField::create('Latitude'),
			HiddenField::create('Longitude'),
			GoogleMapField::create('Map', []),
			UploadField::create('MapPin'),
		]);
	}

	public function onBeforeWrite() {
		parent::onBeforeWrite();
		if (!$this->owner->Region()->ID) {
			$this->owner->SubRegionID = 0;
		}
	}

	public function getAddressFormatted($country = false): string
	{
		$fields = [
			trim($this->getOwner()->Address1 ?: ''),
			trim($this->getOwner()->Address2 ?: ''),
			trim(join(' ', [$this->getOwner()->City, $this->getOwner()->State, $this->getOwner()->Postcode])),
			trim($country ? $this->getOwner()->Country : ''),
		];
		$fields = array_filter($fields, function ($field) {return (bool)$field; });
		return join(' '. PHP_EOL, $fields);
	}

	public function getGoogleMapsLink(): string
	{
		if ($this->getOwner()->MapUrl) return $this->getOwner()->MapUrl;
		$url = 'https://www.google.com/maps/search/?api=1&query=';
		if ($this->owner->Latitude && $this->owner->Longitude) {
			$url .= $this->owner->Latitude . ',' . $this->owner->Longitude;
		} else {
			$url .= urlencode($this->getAddressFormatted(true));
		}
		return $url;
	}

	private function getSubRegionDropdown(): DropdownField
	{
		if ($this->owner->Region()->ID) {
			$subRegions = $this->owner
				->Region()->SubRegions()->map('ID', 'Name')->push('0', 'No Sub Region');
		} else {
			$subRegions = [0 => 'No Sub Region'];
		}
		return DropdownField::create('SubRegionID', 'SubRegion', $subRegions);
	}


}
