<?php


namespace Fastrack\Location;


use Fastrack\Utilities\ModelUtilities;
use PlatoCreative\Imgix\Imgix;
use SilverStripe\Forms\FieldList;
use SilverStripe\Forms\GridField\GridField;
use SilverStripe\Forms\GridField\GridFieldAddNewButton;
use SilverStripe\Forms\GridField\GridFieldConfig_RelationEditor;
use SilverStripe\ORM\DataObject;
use SilverStripe\ORM\FieldType\DBVarchar;
use SilverStripe\ORM\HasManyList;
use Symbiote\GridFieldExtensions\GridFieldAddExistingSearchButton;
use UndefinedOffset\SortableGridField\Forms\GridFieldSortableRows;

/**
 * @property string $Name
 * @property string $Content
 * @method HasManyList Places()
 * @method Imgix Image()
 */
class PlaceCategory extends DataObject
{
	private static string $table_name = 'place_category';

	private static array $db = [
		'Name' => 'Varchar',
		'Content' => 'HTMLText',
	];

	private static array $has_one = [
		'Image' => Imgix::class,
	];

	private static array $belongs_many_many = [
		'Places' => Place::class,
	];

	private static array $translate = [
		'Name',
	];

	private static array $owns = [
		'Image'
	];

	public function getCMSFields(): FieldList
	{
		$fields = parent::getCMSFields();

		$placesConfig = GridFieldConfig_RelationEditor::create(20);
		$placesConfig->removeComponentsByType(GridFieldAddNewButton::class);
		$placesConfig->addComponent(new GridFieldAddExistingSearchButton());
		$placesGrid = GridField::create('Places', 'Places', $this->Places(), $placesConfig);
		$fields->replaceField('Places', $placesGrid);

		ModelUtilities::hideConfigFields($this, $fields);
		return $fields;
	}

}
